@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def likeTermCombineFunc(maxCoef=10, maxExp=20, maxTerms=10, format='string'):
+def gen_func(maxCoef=10, maxExp=20, maxTerms=10, format='string'):
     numTerms = random.randint(1, maxTerms)
     problem = ""
     solution = ""
@@ -18,6 +19,8 @@ def likeTermCombineFunc(maxCoef=10, maxExp=20, maxTerms=10, format='string'):
     solution = combineTerms(problem)
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
@@ -44,5 +47,5 @@ def combineTerms(string):
     return final_string
 
 
-combine_like_terms = Generator("Combine Like terms", 105, likeTermCombineFunc,
+combine_like_terms = Generator("Combine Like terms", 105, gen_func,
                                ["maxCoef=10", "maxExp=20", "maxTerms=10"])
