@@ -1,11 +1,12 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def expandingFunc(range_x1=10,
-                  range_x2=10,
-                  range_a=10,
-                  range_b=10,
-                  format='string'):
+def gen_func(range_x1=10,
+             range_x2=10,
+             range_a=10,
+             range_b=10,
+             format='string'):
     x1 = random.randint(-range_x1, range_x1)
     x2 = random.randint(-range_x2, range_x2)
     a = random.randint(-range_a, range_a)
@@ -48,10 +49,12 @@ def expandingFunc(range_x1=10,
         problem = f"({p1}x{p2})({p3}x{p4})"
         solution = f"{c1}*x^2{c2}*x{c3}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return p1, p2, p3, p4, c1, c2, c3
 
 
 expanding = Generator(
-    "Expanding Factored Binomial", 111, expandingFunc,
+    "Expanding Factored Binomial", 111, gen_func,
     ["range_x1=10", "range_x2=10", "range_a=10", "range_b=10"])
