@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def factoringFunc(range_x1=10, range_x2=10, format='string'):
+def gen_func(range_x1=10, range_x2=10, format='string'):
     x1 = random.randint(-range_x1, range_x1)
     x2 = random.randint(-range_x2, range_x2)
 
@@ -28,9 +29,11 @@ def factoringFunc(range_x1=10, range_x2=10, format='string'):
         x2 = intParser(x2)
         solution = f"(x{x1})(x{x2})"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return b, c, x1, x2
 
 
-factoring = Generator("Factoring Quadratic", 21, factoringFunc,
+factoring = Generator("Factoring Quadratic", 21, gen_func,
                       ["range_x1=10", "range_x2=10"])
