@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def determinantToMatrix22(maxMatrixVal=100, format='string'):
+def gen_func(maxMatrixVal=100, format='string'):
     a = random.randint(0, maxMatrixVal)
     b = random.randint(0, maxMatrixVal)
     c = random.randint(0, maxMatrixVal)
@@ -13,10 +14,12 @@ def determinantToMatrix22(maxMatrixVal=100, format='string'):
         problem = f"Det([[{a}, {b}], [{c}, {d}]]) = "
         solution = f" {determinant}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, d, determinant
 
 
 int_matrix_22_determinant = Generator("Determinant to 2x2 Matrix", 77,
-                                      determinantToMatrix22,
+                                      gen_func,
                                       ["maxMatrixVal=100"])
