@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def linearEquationsFunc(n=2, varRange=20, coeffRange=20, format='string'):
+def gen_func(n=2, varRange=20, coeffRange=20, format='string'):
     if n > 10:
         print("[!] n cannot be greater than 10")
         return None, None
@@ -30,9 +31,11 @@ def linearEquationsFunc(n=2, varRange=20, coeffRange=20, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
-linear_equations = Generator("Linear Equations", 26, linearEquationsFunc,
+linear_equations = Generator("Linear Equations", 26, gen_func,
                              ["n=2", "varRange=20", "coeffRange=20"])
