@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def logFunc(maxBase=3, maxVal=8, format='string'):
+def gen_func(maxBase=3, maxVal=8, format='string'):
     a = random.randint(1, maxVal)
     b = random.randint(2, maxBase)
     c = pow(b, a)
@@ -12,11 +13,10 @@ def logFunc(maxBase=3, maxVal=8, format='string'):
         return problem, solution
     elif format == 'latex':
         problem = "\\(\\log_{" + str(b) + "}" + str(c) + "\\)"
-        print(problem)
         solution = "\\(" + str(a) + "\\)"
         return problem, solution
     else:
         return b, c, a
 
 
-log = Generator("Logarithm", 12, logFunc, ["maxBase=3", "maxVal=8"])
+log = Generator("Logarithm", 12, gen_func, ["maxBase=3", "maxVal=8"])
