@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def MidPointOfTwoPointFunc(maxValue=20, format='string'):
+def gen_func(maxValue=20, format='string'):
     x1 = random.randint(-20, maxValue)
     y1 = random.randint(-20, maxValue)
     x2 = random.randint(-20, maxValue)
@@ -13,9 +14,11 @@ def MidPointOfTwoPointFunc(maxValue=20, format='string'):
         problem = f"({x1},{y1}),({x2},{y2})="
         solution = f"({xm},{ym})"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return x1, y1, x2, y2, xm, ym
 
 
-midPoint_of_two_points = Generator("Midpoint of the two point", 20,
-                                   MidPointOfTwoPointFunc, ["maxValue=20"])
+midpoint_of_two_points = Generator("Midpoint of the two point", 20,
+                                   gen_func, ["maxValue=20"])
