@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def multiplyIntToMatrix22(maxMatrixVal=10, maxRes=100, format='string'):
+def gen_func(maxMatrixVal=10, maxRes=100, format='string'):
     a = random.randint(0, maxMatrixVal)
     b = random.randint(0, maxMatrixVal)
     c = random.randint(0, maxMatrixVal)
@@ -18,7 +19,7 @@ def multiplyIntToMatrix22(maxMatrixVal=10, maxRes=100, format='string'):
         problem = f"{constant} * [[{a}, {b}], [{c}, {d}]] = "
         solution = f"[[{a1},{b1}],[{c1},{d1}]]"
         return problem, solution
-    elif style == 'latex':
+    elif format == 'latex':
         problem = "\\(" + str(constant) + "\\cdot\\begin{bmatrix}" + str(
             a) + "&" + str(b) + "\\\\" + str(c) + "&" + str(
                 d) + "\\end{bmatrix}=\\)"
@@ -30,5 +31,5 @@ def multiplyIntToMatrix22(maxMatrixVal=10, maxRes=100, format='string'):
 
 
 multiply_int_to_22_matrix = Generator("Integer Multiplication with 2x2 Matrix",
-                                      17, multiplyIntToMatrix22,
+                                      17, gen_func,
                                       ["maxMatrixVal=10", "maxRes=100"])
