@@ -1,9 +1,9 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def quadraticEquation(maxVal=100, format='string'):
+def gen_func(maxVal=100, format='string'):
     a = random.randint(1, maxVal)
     c = random.randint(1, maxVal)
     b = random.randint(
@@ -16,9 +16,11 @@ def quadraticEquation(maxVal=100, format='string'):
             a, b, c)
         solution = str(res)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, res
 
 
-quadratic_equation = Generator("Quadratic Equation", 50, quadraticEquation,
+quadratic_equation = Generator("Quadratic Equation", 50, gen_func,
                                ["maxVal=100"])
