@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def simpleInterestFunc(maxPrinciple=10000,
-                       maxRate=10,
-                       maxTime=10,
-                       format='string'):
+def gen_func(maxPrinciple=10000,
+             maxRate=10,
+             maxTime=10,
+             format='string'):
     a = random.randint(1000, maxPrinciple)
     b = random.randint(1, maxRate)
     c = random.randint(1, maxTime)
@@ -17,9 +18,11 @@ def simpleInterestFunc(maxPrinciple=10000,
                     c) + " years is = "
         solution = str(d)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, d
 
 
-simple_interest = Generator("Simple Interest", 45, simpleInterestFunc,
+simple_interest = Generator("Simple Interest", 45, gen_func,
                             ["maxPrinciple=10000", "maxRate=10", "maxTime=10"])
