@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def systemOfEquationsFunc(range_x=10,
-                          range_y=10,
-                          coeff_mult_range=10,
-                          format='string'):
+def gen_func(range_x=10,
+             range_y=10,
+             coeff_mult_range=10,
+             format='string'):
     # Generate solution point first
     x = random.randint(-range_x, range_x)
     y = random.randint(-range_y, range_y)
@@ -48,11 +49,13 @@ def systemOfEquationsFunc(range_x=10,
         problem = f"{coeffToFuncString(new_c1)}, {coeffToFuncString(new_c2)}"
         solution = f"x = {x}, y = {y}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return new_c1, new_c2, x, y
     # Add random (non-zero) multiple of equations to each other
 
 
 system_of_equations = Generator(
-    "Solve a System of Equations in R^2", 23, systemOfEquationsFunc,
+    "Solve a System of Equations in R^2", 23, gen_func,
     ["range_x=10", "range_y=10", "coeff_mult_range=10"])
