@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def vectorCrossFunc(minVal=-20, maxVal=20, format='string'):
+def gen_func(minVal=-20, maxVal=20, format='string'):
     a = [random.randint(minVal, maxVal) for i in range(3)]
     b = [random.randint(minVal, maxVal) for i in range(3)]
     c = [
@@ -13,9 +14,11 @@ def vectorCrossFunc(minVal=-20, maxVal=20, format='string'):
         problem = str(a) + " X " + str(b) + " = "
         solution = str(c)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c
 
 
-vector_cross = Generator("Cross Product of 2 Vectors", 43, vectorCrossFunc,
+vector_cross = Generator("Cross Product of 2 Vectors", 43, gen_func,
                          ["minVal=-20", "maxVal=20"])
