@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def vectorDotFunc(minVal=-20, maxVal=20, format='string'):
+def gen_func(minVal=-20, maxVal=20, format='string'):
     a = [random.randint(minVal, maxVal) for i in range(3)]
     b = [random.randint(minVal, maxVal) for i in range(3)]
     c = a[0] * b[0] + a[1] * b[1] + a[2] * b[2]
@@ -10,9 +11,11 @@ def vectorDotFunc(minVal=-20, maxVal=20, format='string'):
         problem = str(a) + " . " + str(b) + " = "
         solution = str(c)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c
 
 
-vector_dot = Generator("Dot Product of 2 Vectors", 72, vectorDotFunc,
+vector_dot = Generator("Dot Product of 2 Vectors", 72, gen_func,
                        ["minVal=-20", "maxVal=20"])
