@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def factorialFunc(maxInput=6, format='string'):
+def gen_func(maxInput=6, format='string'):
     a = random.randint(0, maxInput)
     n = a
     b = 1
@@ -11,8 +12,10 @@ def factorialFunc(maxInput=6, format='string'):
 
     if format == 'string':
         return str(a) + "! = ", str(b)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b
 
 
-factorial = Generator("Factorial", 31, factorialFunc, ["maxInput=6"])
+factorial = Generator("Factorial", 31, gen_func, ["maxInput=6"])
