@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def isprime(max_num=100, format='string'):
+def gen_func(max_num=100, format='string'):
     a = random.randint(2, max_num)
     problem = f"Is {a} prime?"
     if a == 2:
@@ -18,8 +19,10 @@ def isprime(max_num=100, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, solution
 
 
-is_prime = Generator('isprime', 90, isprime, ["max_num=100"])
+is_prime = Generator('isprime', 90, gen_func, ["max_num=100"])
