@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def percentageFunc(maxValue=99, maxpercentage=99, format='string'):
+def gen_func(maxValue=99, maxpercentage=99, format='string'):
     a = random.randint(1, maxpercentage)
     b = random.randint(1, maxValue)
     problem = f"What is {a}% of {b}?"
@@ -11,9 +12,11 @@ def percentageFunc(maxValue=99, maxpercentage=99, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, formatted_float
 
 
-percentage = Generator("Percentage of a number", 80, percentageFunc,
+percentage = Generator("Percentage of a number", 80, gen_func,
                        ["maxValue=99", "maxpercentage=99"])
