@@ -1,9 +1,9 @@
-from .__init__ import *
-import scipy
+from ...__init__ import Generator
+import random
 from scipy.integrate import quad
 
 
-def definiteIntegralFunc(max_coeff=100, format='string'):
+def gen_func(max_coeff=100, format='string'):
     def integrand(x, a, b, c):
         return a * x**2 + b * x + c
 
@@ -19,9 +19,11 @@ def definiteIntegralFunc(max_coeff=100, format='string'):
             str(a) + "x^2 + " + str(b) + "x + " + str(c) + " is = "
         solution = str(S)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, S
 
 
 definite_integral = Generator("Definite Integral of Quadratic Equation", 89,
-                              definiteIntegralFunc, ["max_coeff=100"])
+                              gen_func, ["max_coeff=100"])
