@@ -1,4 +1,6 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+import sympy
 
 
 def genDifferentiationProblem(diff_lvl=2):
@@ -34,7 +36,7 @@ def genDifferentiationProblem(diff_lvl=2):
     return problem
 
 
-def differentiationFunc(diff_lvl=2, format='string'):
+def gen_func(diff_lvl=2, format='string'):
     if diff_lvl < 1 or diff_lvl > 4:
         print("diff_lvl not supported")
         return None
@@ -47,9 +49,11 @@ def differentiationFunc(diff_lvl=2, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
-differentiation = Generator("Differentiation", 88, differentiationFunc,
+differentiation = Generator("Differentiation", 88, gen_func,
                             ["diff_lvl=2"])
