@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def powerRuleDifferentiationFunc(maxCoef=10,
-                                 maxExp=10,
-                                 maxTerms=5,
-                                 format='string'):
+def gen_func(maxCoef=10,
+             maxExp=10,
+             maxTerms=5,
+             format='string'):
     numTerms = random.randint(1, maxTerms)
     problem = ""
     solution = ""
@@ -21,10 +22,12 @@ def powerRuleDifferentiationFunc(maxCoef=10,
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
 power_rule_differentiation = Generator(
-    "Power Rule Differentiation", 7, powerRuleDifferentiationFunc,
+    "Power Rule Differentiation", 7, gen_func,
     ["maxCoef=10", "maxExp=10", "maxTerms=5"])
