@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def powerRuleIntegrationFunc(maxCoef=10,
-                             maxExp=10,
-                             maxTerms=5,
-                             format='string'):
+def gen_func(maxCoef=10,
+             maxExp=10,
+             maxTerms=5,
+             format='string'):
     numTerms = random.randint(1, maxTerms)
     problem = ""
     solution = ""
@@ -24,10 +25,12 @@ def powerRuleIntegrationFunc(maxCoef=10,
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
 power_rule_integration = Generator("Power Rule Integration", 48,
-                                   powerRuleIntegrationFunc,
+                                   gen_func,
                                    ["maxCoef=10", "maxExp=10", "maxTerms=5"])
