@@ -1,8 +1,9 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 import sympy
 
 
-def stationaryPointsFunc(maxExp=3, maxCoef=10, format='string'):
+def gen_func(maxExp=3, maxCoef=10, format='string'):
     while True:
         x = sympy.symbols('x')
         problem = 0
@@ -18,9 +19,11 @@ def stationaryPointsFunc(maxExp=3, maxCoef=10, format='string'):
         problem = 'f(x)=' + str(problem).replace('**', '^')
         if format == 'string':
             return problem, solution
+        elif format == 'latex':
+            return "Latex unavailable"
         else:
             return problem, solution
 
 
-stationary_points = Generator("Stationary Points", 110, stationaryPointsFunc,
+stationary_points = Generator("Stationary Points", 110, gen_func,
                               ["maxExp=3", "maxCoef=10"])
