@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def BCDtoDecimalFunc(maxNumber=10000, format='string'):
+def gen_func(maxNumber=10000, format='string'):
     n = random.randint(1000, maxNumber)
     binstring = ''
     while True:
@@ -19,9 +20,11 @@ def BCDtoDecimalFunc(maxNumber=10000, format='string'):
         problem = "Integer of Binary Coded Decimal " + str(n) + " is = "
         solution = int(binstring, 2)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return n, int(binstring, 2)
 
 
 bcd_to_decimal = Generator("Binary Coded Decimal to Integer", 91,
-                           BCDtoDecimalFunc, ["maxNumber=10000"])
+                           gen_func, ["maxNumber=10000"])
