@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def binary2sComplementFunc(maxDigits=10, format='string'):
+def gen_func(maxDigits=10, format='string'):
     digits = random.randint(1, maxDigits)
     question = ''.join([str(random.randint(0, 1))
                         for i in range(digits)]).lstrip('0')
@@ -27,9 +28,11 @@ def binary2sComplementFunc(maxDigits=10, format='string'):
         problem = "2's complement of " + question + " ="
         solution = ''.join(answer).lstrip('0')
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return question, answer
 
 
 binary_2s_complement = Generator("Binary 2's Complement", 73,
-                                 binary2sComplementFunc, ["maxDigits=10"])
+                                 gen_func, ["maxDigits=10"])
