@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def binaryComplement1sFunc(maxDigits=10, format='string'):
+def gen_func(maxDigits=10, format='string'):
     question = ''
     answer = ''
 
@@ -13,9 +14,11 @@ def binaryComplement1sFunc(maxDigits=10, format='string'):
     if format == 'string':
         problem = question + "="
         return problem, answer
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, answer
 
 
 binary_complement_1s = Generator("Binary Complement 1s", 4,
-                                 binaryComplement1sFunc, ["maxDigits=10"])
+                                 gen_func, ["maxDigits=10"])
