@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def binaryToDecimalFunc(max_dig=10, format='string'):
+def gen_func(max_dig=10, format='string'):
     problem = ''
 
     for i in range(random.randint(1, max_dig)):
@@ -11,9 +12,11 @@ def binaryToDecimalFunc(max_dig=10, format='string'):
     if format == 'string':
         solution = int(problem, 2)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
-binary_to_decimal = Generator("Binary to Decimal", 15, binaryToDecimalFunc,
+binary_to_decimal = Generator("Binary to Decimal", 15, gen_func,
                               ["max_dig=10"])
