@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def binaryToHexFunc(max_dig=10, format='string'):
+def gen_func(max_dig=10, format='string'):
     problem = ''
     for i in range(random.randint(1, max_dig)):
         temp = str(random.randint(0, 1))
@@ -10,9 +11,11 @@ def binaryToHexFunc(max_dig=10, format='string'):
     if format == 'string':
         solution = hex(int(problem, 2))
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return problem, solution
 
 
-binary_to_hex = Generator("Binary to Hexidecimal", 64, binaryToHexFunc,
+binary_to_hex = Generator("Binary to Hexidecimal", 64, gen_func,
                           ["max_dig=10"])
