@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def fibonacciSeriesFunc(minNo=1, format='string'):
+def gen_func(minNo=1, format='string'):
     n = random.randint(minNo, 20)
 
     def createFibList(n):
@@ -20,9 +21,11 @@ def fibonacciSeriesFunc(minNo=1, format='string'):
         problem = "The Fibonacci Series of the first " + str(
             n) + " numbers is ?"
         return problem, fibList
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return n, fibList
 
 
-fibonacci_series = Generator("Fibonacci Series", 56, fibonacciSeriesFunc,
+fibonacci_series = Generator("Fibonacci Series", 56, gen_func,
                              ["minNo=1"])
