@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def regularPolygonAngleFunc(minVal=3, maxVal=20, format='string'):
+def gen_func(minVal=3, maxVal=20, format='string'):
     sideNum = random.randint(minVal, maxVal)
     problem = f"Find the angle of a regular polygon with {sideNum} sides"
 
@@ -10,10 +11,12 @@ def regularPolygonAngleFunc(minVal=3, maxVal=20, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return sideNum, solution
 
 
 angle_regular_polygon = Generator("Angle of a Regular Polygon", 29,
-                                  regularPolygonAngleFunc,
+                                  gen_func,
                                   ["minVal=3", "maxVal=20"])
