@@ -1,9 +1,9 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def arclengthFunc(maxRadius=49, maxAngle=359, format='string'):
+def gen_func(maxRadius=49, maxAngle=359, format='string'):
     radius = random.randint(1, maxRadius)
     angle = random.randint(1, maxAngle)
     problem = f"Given radius, {radius} and angle, {angle}. Find the arc length of the angle."
@@ -13,9 +13,11 @@ def arclengthFunc(maxRadius=49, maxAngle=359, format='string'):
     if format == 'string':
         solution = f"Arc length of the angle = {formatted_float}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return radius, angle, formatted_float
 
 
-arc_length = Generator("Arc length of Angle", 108, arclengthFunc,
+arc_length = Generator("Arc length of Angle", 108, gen_func,
                        ["maxRadius=49", "maxAngle=359"])
