@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def areaCircle(maxRadius=100, format='string'):
+def gen_func(maxRadius=100, format='string'):
     r = random.randint(0, maxRadius)
     pi = 22 / 7
     area = pi * r * r
@@ -9,9 +10,11 @@ def areaCircle(maxRadius=100, format='string'):
     if format == 'string':
         problem = f"Area of circle with radius {r}"
         return problem, str(area)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return r, area
 
 
-area_of_circle = Generator("Area of Circle", 112, areaCircle,
+area_of_circle = Generator("Area of Circle", 112, gen_func,
                            ["maxRadius=100"])
