@@ -1,12 +1,12 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
 # Handles degrees in quadrant one
-def basicTrigonometryFunc(angles=[0, 30, 45, 60, 90],
-                          functions=["sin", "cos", "tan"],
-                          format='string'):
+def gen_func(angles=[0, 30, 45, 60, 90],
+             functions=["sin", "cos", "tan"],
+             format='string'):
     angle = random.choice(angles)
     function = random.choice(functions)
 
@@ -28,10 +28,12 @@ def basicTrigonometryFunc(angles=[0, 30, 45, 60, 90],
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return function, angle, solution
 
 
 basic_trigonometry = Generator(
-    "Trigonometric Values", 57, basicTrigonometryFunc,
+    "Trigonometric Values", 57, gen_func,
     ["angles=[0, 30, 45, 60, 90]", "functions=['sin', 'cos', 'tan']"])
