@@ -1,19 +1,22 @@
-from .__init__ import *
-from numpy import pi
+from ...__init__ import Generator
+import random
+import math
 
 
-def degreeToRadFunc(max_deg=360, format='string'):
+def gen_func(max_deg=360, format='string'):
     a = random.randint(0, max_deg)
-    b = (pi * a) / 180
+    b = (math.pi * a) / 180
     b = round(b, 2)
 
     if format == 'string':
         problem = "Angle " + str(a) + " in radians is = "
         solution = str(b)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b
 
 
-degree_to_rad = Generator("Degrees to Radians", 86, degreeToRadFunc,
+degree_to_rad = Generator("Degrees to Radians", 86, gen_func,
                           ["max_deg=360"])
