@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def fourthAngleOfQuadriFunc(maxAngle=180, format='string'):
+def gen_func(maxAngle=180, format='string'):
     angle1 = random.randint(1, maxAngle)
     angle2 = random.randint(1, 240 - angle1)
     angle3 = random.randint(1, 340 - (angle1 + angle2))
@@ -13,10 +14,12 @@ def fourthAngleOfQuadriFunc(maxAngle=180, format='string'):
         problem = f"Fourth angle of quadrilateral with angles {angle1} , {angle2}, {angle3} ="
         solution = angle4
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return angle1, angle2, angle3, angle4
 
 
 fourth_angle_of_quadrilateral = Generator("Fourth Angle of Quadrilateral", 49,
-                                          fourthAngleOfQuadriFunc,
+                                          gen_func,
                                           ["maxAngle=180"])
