@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def perimeterOfPolygons(maxSides=12, maxLength=120, format='string'):
+def gen_func(maxSides=12, maxLength=120, format='string'):
     size_of_sides = random.randint(3, maxSides)
     sides = []
     for x in range(size_of_sides):
@@ -14,10 +15,12 @@ def perimeterOfPolygons(maxSides=12, maxLength=120, format='string'):
 
     if format == 'string':
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return size_of_sides, sides, solution
 
 
 perimeter_of_polygons = Generator("Perimeter of Polygons", 96,
-                                  perimeterOfPolygons,
+                                  gen_func,
                                   ["maxSides=12", "maxLength=120"])
