@@ -1,7 +1,9 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+import math
 
 
-def sectorAreaFunc(maxRadius=49, maxAngle=359, format='string'):
+def gen_func(maxRadius=49, maxAngle=359, format='string'):
     r = random.randint(1, maxRadius)
     a = random.randint(1, maxAngle)
     secArea = float((a / 360) * math.pi * r * r)
@@ -11,9 +13,11 @@ def sectorAreaFunc(maxRadius=49, maxAngle=359, format='string'):
         problem = f"Given radius, {r} and angle, {a}. Find the area of the sector."
         solution = f"Area of sector = {formatted_float}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return r, a, formatted_float
 
 
-sector_area = Generator("Area of a Sector", 75, sectorAreaFunc,
+sector_area = Generator("Area of a Sector", 75, gen_func,
                         ["maxRadius=49", "maxAngle=359"])
