@@ -1,7 +1,9 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+import math
 
 
-def surfaceAreaCone(maxRadius=20, maxHeight=50, unit='m', format='string'):
+def gen_func(maxRadius=20, maxHeight=50, unit='m', format='string'):
     a = random.randint(1, maxHeight)
     b = random.randint(1, maxRadius)
 
@@ -12,9 +14,11 @@ def surfaceAreaCone(maxRadius=20, maxHeight=50, unit='m', format='string'):
         problem = f"Surface area of cone with height = {a}{unit} and radius = {b}{unit} is"
         solution = f"{ans} {unit}^2"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, ans, unit
 
 
-surface_area_cone = Generator("Surface Area of cone", 38, surfaceAreaCone,
+surface_area_cone = Generator("Surface Area of cone", 38, gen_func,
                               ["maxRadius=20", "maxHeight=50", "unit='m'"])
