@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def surfaceAreaCube(maxSide=20, unit='m', format='string'):
+def gen_func(maxSide=20, unit='m', format='string'):
     a = random.randint(1, maxSide)
     ans = 6 * a * a
 
@@ -9,9 +10,11 @@ def surfaceAreaCube(maxSide=20, unit='m', format='string'):
         problem = f"Surface area of cube with side = {a}{unit} is"
         solution = f"{ans} {unit}^2"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, ans, unit
 
 
-surface_area_cube = Generator("Surface Area of Cube", 32, surfaceAreaCube,
+surface_area_cube = Generator("Surface Area of Cube", 32, gen_func,
                               ["maxSide=20", "unit='m'"])
