@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def surfaceAreaCuboid(maxSide=20, unit='m', format='string'):
+def gen_func(maxSide=20, unit='m', format='string'):
     a = random.randint(1, maxSide)
     b = random.randint(1, maxSide)
     c = random.randint(1, maxSide)
@@ -11,9 +12,11 @@ def surfaceAreaCuboid(maxSide=20, unit='m', format='string'):
         problem = f"Surface area of cuboid with sides = {a}{unit}, {b}{unit}, {c}{unit} is"
         solution = f"{ans} {unit}^2"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, ans, unit
 
 
 surface_area_cuboid = Generator("Surface Area of Cuboid", 33,
-                                surfaceAreaCuboid, ["maxSide=20", "unit='m'"])
+                                gen_func, ["maxSide=20", "unit='m'"])
