@@ -1,7 +1,9 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+import math
 
 
-def surfaceAreaSphere(maxSide=20, unit='m', format='string'):
+def gen_func(maxSide=20, unit='m', format='string'):
     r = random.randint(1, maxSide)
     ans = 4 * math.pi * r * r
 
@@ -9,9 +11,11 @@ def surfaceAreaSphere(maxSide=20, unit='m', format='string'):
         problem = f"Surface area of Sphere with radius = {r}{unit} is"
         solution = f"{ans} {unit}^2"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return r, ans, unit
 
 
 surface_area_sphere = Generator("Surface Area of Sphere", 60,
-                                surfaceAreaSphere, ["maxSide=20", "unit='m'"])
+                                gen_func, ["maxSide=20", "unit='m'"])
