@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def isTriangleValidFunc(maxSideLength=50, format='string'):
+def gen_func(maxSideLength=50, format='string'):
     sideA = random.randint(1, maxSideLength)
     sideB = random.randint(1, maxSideLength)
     sideC = random.randint(1, maxSideLength)
@@ -19,9 +20,11 @@ def isTriangleValidFunc(maxSideLength=50, format='string'):
         else:
             solution = "No"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return sideA, sideB, sideC, exists
 
 
-valid_triangle = Generator("Triangle exists check", 19, isTriangleValidFunc,
+valid_triangle = Generator("Triangle exists check", 19, gen_func,
                            ["maxSideLength=50"])
