@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def volumeCuboid(maxSide=20, unit='m', format='string'):
+def gen_func(maxSide=20, unit='m', format='string'):
     a = random.randint(1, maxSide)
     b = random.randint(1, maxSide)
     c = random.randint(1, maxSide)
@@ -11,9 +12,11 @@ def volumeCuboid(maxSide=20, unit='m', format='string'):
         problem = f"Volume of cuboid with sides = {a}{unit}, {b}{unit}, {c}{unit} is"
         solution = f"{ans} {unit}^3"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, c, ans, unit
 
 
-volume_cuboid = Generator("Volume of Cuboid", 36, volumeCuboid,
+volume_cuboid = Generator("Volume of Cuboid", 36, gen_func,
                           ["maxSide=20", "unit='m'"])
