@@ -1,7 +1,9 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+import math
 
 
-def volumeCylinder(maxRadius=20, maxHeight=50, unit='m', format='string'):
+def gen_func(maxRadius=20, maxHeight=50, unit='m', format='string'):
     a = random.randint(1, maxHeight)
     b = random.randint(1, maxRadius)
     ans = int(math.pi * b * b * a)
@@ -10,9 +12,11 @@ def volumeCylinder(maxRadius=20, maxHeight=50, unit='m', format='string'):
         problem = f"Volume of cylinder with height = {a}{unit} and radius = {b}{unit} is"
         solution = f"{ans} {unit}^3"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, ans, unit
 
 
-volume_cylinder = Generator("Volume of cylinder", 37, volumeCylinder,
+volume_cylinder = Generator("Volume of cylinder", 37, gen_func,
                             ["maxRadius=20", "maxHeight=50", "unit='m'"])
