@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def arithmeticProgressionSumFunc(maxd=100,
-                                 maxa=100,
-                                 maxn=100,
-                                 format='string'):
+def gen_func(maxd=100,
+             maxa=100,
+             maxn=100,
+             format='string'):
     d = random.randint(-1 * maxd, maxd)
     a1 = random.randint(-1 * maxa, maxa)
     a2 = a1 + d
@@ -18,10 +19,12 @@ def arithmeticProgressionSumFunc(maxd=100,
         problem = 'Find the sum of first ' + \
             str(n) + ' terms of the AP series: ' + apString
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return n, apString, solution
 
 
 arithmetic_progression_sum = Generator("AP Sum Calculation", 83,
-                                       arithmeticProgressionSumFunc,
+                                       gen_func,
                                        ["maxd=100", "maxa=100", "maxn=100"])
