@@ -1,10 +1,11 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def arithmeticProgressionTermFunc(maxd=100,
-                                  maxa=100,
-                                  maxn=100,
-                                  format='string'):
+def gen_func(maxd=100,
+             maxa=100,
+             maxn=100,
+             format='string'):
     d = random.randint(-1 * maxd, maxd)
     a1 = random.randint(-1 * maxa, maxa)
     a2 = a1 + d
@@ -17,10 +18,12 @@ def arithmeticProgressionTermFunc(maxd=100,
         problem = 'Find the term number ' + str(
             n) + ' of the AP series: ' + apString
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return n, apString, solution
 
 
 arithmetic_progression_term = Generator("AP Term Calculation", 82,
-                                        arithmeticProgressionTermFunc,
+                                        gen_func,
                                         ["maxd=100", "maxa=100", "maxn=100"])
