@@ -1,4 +1,6 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
+
 
 # base from 2 to 36
 alpha = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
@@ -30,7 +32,7 @@ def fromBaseTenTo(n, toBase):
 #     return int(n,fromBase)
 
 
-def baseConversionFunc(maxNum=60000, maxBase=16, format='string'):
+def gen_func(maxNum=60000, maxBase=16, format='string'):
     assert type(
         maxNum
     ) == int and maxNum >= 100 and maxNum <= 65536, "maxNum({}) must be >=100 and <=65536".format(
@@ -52,10 +54,12 @@ def baseConversionFunc(maxNum=60000, maxBase=16, format='string'):
             fromBaseTenTo(n, bases[0]), bases[0], bases[1])
         ans = fromBaseTenTo(n, bases[1])
         return problem, ans
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return fromBaseTenTo(n, bases[0]), bases[0], bases[1], fromBaseTenTo(
             n, bases[1])
 
 
-base_conversion = Generator("Base Conversion", 94, baseConversionFunc,
+base_conversion = Generator("Base Conversion", 94, gen_func,
                             ["maxNum=60000", "maxBase=16"])
