@@ -1,4 +1,5 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
 def factorial(n):
@@ -13,7 +14,7 @@ def newton_symbol(n, k):
     return factorial(n) / (factorial(k) * factorial(n - k))
 
 
-def binomialDistFunc(format='string'):
+def gen_func(format='string'):
     rejected_fraction = float(random.randint(30, 40)) + random.random()
     batch = random.randint(10, 20)
     rejections = random.randint(1, 9)
@@ -33,9 +34,11 @@ def binomialDistFunc(format='string'):
             "batch of {1:} pistons will contain no more than {2:} " \
             "rejected pistons?".format(rejected_fraction, batch, rejections)
         return problem, answer
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return rejected_fraction, batch, rejections, answer
 
 
 binomial_distribution = Generator("Binomial distribution", 109,
-                                  binomialDistFunc, [""])
+                                  gen_func, [""])
