@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def celsiustofahrenheitFunc(maxTemp=100, format='string'):
+def gen_func(maxTemp=100, format='string'):
     celsius = random.randint(-50, maxTemp)
     fahrenheit = (celsius * (9 / 5)) + 32
 
@@ -10,9 +11,11 @@ def celsiustofahrenheitFunc(maxTemp=100, format='string'):
             celsius) + " degrees Celsius to degrees Fahrenheit ="
         solution = str(fahrenheit)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return celsius, fahrenheit
 
 
 celsius_to_fahrenheit = Generator("Celsius To Fahrenheit", 81,
-                                  celsiustofahrenheitFunc, ["maxTemp=100"])
+                                  gen_func, ["maxTemp=100"])
