@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def commonFactorsFunc(maxVal=100, format='string'):
+def gen_func(maxVal=100, format='string'):
     a = x = random.randint(1, maxVal)
     b = y = random.randint(1, maxVal)
 
@@ -23,9 +24,11 @@ def commonFactorsFunc(maxVal=100, format='string'):
         problem = f"Common Factors of {a} and {b} = "
         solution = arr
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, arr
 
 
-common_factors = Generator("Common Factors", 40, commonFactorsFunc,
+common_factors = Generator("Common Factors", 40, gen_func,
                            ["maxVal=100"])
