@@ -1,11 +1,11 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def complexToPolarFunc(minRealImaginaryNum=-20,
-                       maxRealImaginaryNum=20,
-                       format='string'):
+def gen_func(minRealImaginaryNum=-20,
+             maxRealImaginaryNum=20,
+             format='string'):
     num = complex(random.randint(minRealImaginaryNum, maxRealImaginaryNum),
                   random.randint(minRealImaginaryNum, maxRealImaginaryNum))
     a = num.real
@@ -16,10 +16,12 @@ def complexToPolarFunc(minRealImaginaryNum=-20,
     if format == 'string':
         problem = f'{r}({a}theta + i{b}theta)'
         return problem, theta
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return r, a, b, theta
 
 
 complex_to_polar = Generator(
-    "Complex To Polar Form", 92, complexToPolarFunc,
+    "Complex To Polar Form", 92, gen_func,
     ["minRealImaginaryNum=-20, maxRealImaginaryNum=20"])
