@@ -1,9 +1,9 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def euclidianNormFunc(maxEltAmt=20, format='string'):
+def gen_func(maxEltAmt=20, format='string'):
     vec = [
         random.uniform(0, 1000) for i in range(random.randint(2, maxEltAmt))
     ]
@@ -12,9 +12,11 @@ def euclidianNormFunc(maxEltAmt=20, format='string'):
     if format == 'string':
         problem = f"Euclidian norm or L2 norm of the vector{vec} is:"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return vec, solution
 
 
-eucldian_norm = Generator("Euclidian norm or L2 norm of a vector", 69,
-                          euclidianNormFunc, ["maxEltAmt=20"])
+euclidian_norm = Generator("Euclidian norm or L2 norm of a vector", 69,
+                           gen_func, ["maxEltAmt=20"])
