@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def gcdFunc(maxVal=20, format='string'):
+def gen_func(maxVal=20, format='string'):
     a = random.randint(1, maxVal)
     b = random.randint(1, maxVal)
     x, y = a, b
@@ -12,9 +13,11 @@ def gcdFunc(maxVal=20, format='string'):
         problem = f"GCD of {a} and {b} = "
         solution = str(x)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, x
 
 
-gcd = Generator("GCD (Greatest Common Denominator)", 10, gcdFunc,
+gcd = Generator("GCD (Greatest Common Denominator)", 10, gen_func,
                 ["maxVal=20"])
