@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def hcfFunc(maxVal=20, format='string'):
+def gen_func(maxVal=20, format='string'):
     a = random.randint(1, maxVal)
     b = random.randint(1, maxVal)
     x, y = a, b
@@ -12,8 +13,10 @@ def hcfFunc(maxVal=20, format='string'):
         problem = f"HCF of {a} and {b} = "
         solution = str(x)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, x
 
 
-hcf = Generator("HCF (Highest Common Factor)", 51, hcfFunc, ["maxVal=20"])
+hcf = Generator("HCF (Highest Common Factor)", 51, gen_func, ["maxVal=20"])
