@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def IsLeapYear(minNumber=1900, maxNumber=2099, format='string'):
+def gen_func(minNumber=1900, maxNumber=2099, format='string'):
     year = random.randint(minNumber, maxNumber)
     problem = "Year " + str(year) + " "
     if (year % 4) == 0:
@@ -21,9 +22,11 @@ def IsLeapYear(minNumber=1900, maxNumber=2099, format='string'):
         else:
             solution = "is not a leap year"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return year, ans
 
 
-is_leap_year = Generator("Leap Year or Not", 101, IsLeapYear,
+is_leap_year = Generator("Leap Year or Not", 101, gen_func,
                          ["minNumber=1900", "maxNumber=2099"])
