@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def lcmFunc(maxVal=20, format='string'):
+def gen_func(maxVal=20, format='string'):
     a = random.randint(1, maxVal)
     b = random.randint(1, maxVal)
     c = a * b
@@ -15,8 +16,10 @@ def lcmFunc(maxVal=20, format='string'):
         problem = f"LCM of {a} and {b} ="
         solution = str(d)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, d
 
 
-lcm = Generator("LCM (Least Common Multiple)", 9, lcmFunc, ["maxVal=20"])
+lcm = Generator("LCM (Least Common Multiple)", 9, gen_func, ["maxVal=20"])
