@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def primeFactorsFunc(minVal=1, maxVal=200, format='string'):
+def gen_func(minVal=1, maxVal=200, format='string'):
     a = random.randint(minVal, maxVal)
     n = a
     i = 2
@@ -21,9 +22,11 @@ def primeFactorsFunc(minVal=1, maxVal=200, format='string'):
         problem = f"Find prime factors of {a}"
         solution = f"{factors}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, factors
 
 
-prime_factors = Generator("Prime Factorisation", 27, primeFactorsFunc,
+prime_factors = Generator("Prime Factorisation", 27, gen_func,
                           ["minVal=1", "maxVal=200"])
