@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def profitLossPercentFunc(maxCP=1000, maxSP=1000, format='string'):
+def gen_func(maxCP=1000, maxSP=1000, format='string'):
     cP = random.randint(1, maxCP)
     sP = random.randint(1, maxSP)
     diff = abs(sP - cP)
@@ -14,10 +15,12 @@ def profitLossPercentFunc(maxCP=1000, maxSP=1000, format='string'):
     if format == 'string':
         problem = f"{profitOrLoss} percent when CP = {cP} and SP = {sP} is: "
         return problem, str(percent)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return profitOrLoss, cP, sP, percent
 
 
 profit_loss_percent = Generator("Profit or Loss Percent", 63,
-                                profitLossPercentFunc,
+                                gen_func,
                                 ["maxCP=1000", "maxSP=1000"])
