@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def quotientOfPowerSameBaseFunc(maxBase=50, maxPower=10, format='string'):
+def gen_func(maxBase=50, maxPower=10, format='string'):
     base = random.randint(1, maxBase)
     power1 = random.randint(1, maxPower)
     power2 = random.randint(1, maxPower)
@@ -12,10 +13,12 @@ def quotientOfPowerSameBaseFunc(maxBase=50, maxPower=10, format='string'):
         problem = f"The Quotient of {base}^{power1} and {base}^{power2} = " \
             f"{base}^({power1}-{power2}) = {base}^{step}"
         return problem, str(solution)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return base, power1, power2, step, solution
 
 
 quotient_of_power_same_base = Generator("Quotient of Powers with Same Base",
-                                        98, quotientOfPowerSameBaseFunc,
+                                        98, gen_func,
                                         ["maxBase=50", "maxPower=10"])
