@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def quotientOfPowerSamePowerFunc(maxBase=50, maxPower=10, format='string'):
+def gen_func(maxBase=50, maxPower=10, format='string'):
     base1 = random.randint(1, maxBase)
     base2 = random.randint(1, maxBase)
     power = random.randint(1, maxPower)
@@ -12,10 +13,12 @@ def quotientOfPowerSamePowerFunc(maxBase=50, maxPower=10, format='string'):
         problem = f"The Quotient of {base1}^{power} and {base2}^{power} = " \
             f"({base1}/{base2})^{power} = {step}^{power}"
         return problem, str(solution)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return base1, base2, power, step, solution
 
 
 quotient_of_power_same_power = Generator("Quotient of Powers with Same Power",
-                                         99, quotientOfPowerSamePowerFunc,
+                                         99, gen_func,
                                          ["maxBase=50", "maxPower=10"])
