@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def set_operation(minval=3, maxval=7, n_a=4, n_b=5, format='string'):
+def gen_func(minval=3, maxval=7, n_a=4, n_b=5, format='string'):
     number_variables_a = random.randint(minval, maxval)
     number_variables_b = random.randint(minval, maxval)
     a = []
@@ -24,5 +25,5 @@ def set_operation(minval=3, maxval=7, n_a=4, n_b=5, format='string'):
 
 
 set_operation = Generator("Union,Intersection,Difference of Two Sets", 93,
-                          set_operation,
+                          gen_func,
                           ["minval=3", "maxval=7", "n_a=4", "n_b=5"])
