@@ -1,8 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
 import random
 
 
-def signumFunc(min=-999, max=999, format='string'):
+def gen_func(min=-999, max=999, format='string'):
     a = random.randint(min, max)
     b = 0
     if (a > 0):
@@ -14,9 +14,11 @@ def signumFunc(min=-999, max=999, format='string'):
         problem = "signum of " + str(a) + " is " + "="
         solution = str(b)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b
 
 
-signum_function = Generator("signum function", 106, signumFunc,
+signum_function = Generator("signum function", 106, gen_func,
                             ["min=-999", "max=999"])
