@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def combinationsFunc(maxlength=20, format='string'):
+def gen_func(maxlength=20, format='string'):
     def factorial(a):
         d = 1
         for i in range(a):
@@ -17,9 +18,11 @@ def combinationsFunc(maxlength=20, format='string'):
     if format == 'string':
         problem = f"Number of combinations from {a} objects picked {b} at a time "
         return problem, str(solution)
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, solution
 
 
-combinations = Generator("Combinations of Objects", 30, combinationsFunc,
+combinations = Generator("Combinations of Objects", 30, gen_func,
                          ["maxlength=20"])
