@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def conditionalProbFunc(format='string'):
+def gen_func(format='string'):
     P_disease = round(2. * random.random(), 2)
     true_positive = round(random.random() + float(random.randint(90, 99)), 2)
     true_negative = round(random.random() + float(random.randint(90, 99)), 2)
@@ -24,9 +25,11 @@ def conditionalProbFunc(format='string'):
                 P_disease, true_positive, true_negative)
         solution = str(answer) + "%"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return P_disease, true_positive, true_negative, answer
 
 
 conditional_probability = Generator("Conditional Probability", 107,
-                                    conditionalProbFunc, [""])
+                                    gen_func, [""])
