@@ -1,9 +1,9 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def confidenceIntervalFunc(format='string'):
+def gen_func(format='string'):
     n = random.randint(20, 40)
     j = random.randint(0, 3)
 
@@ -34,9 +34,11 @@ def confidenceIntervalFunc(format='string'):
             [x for x in lst], lst_per[j])
         solution = f'({upper}, {lower})'
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return [x for x in lst], lst_per[j], upper, lower
 
 
 confidence_interval = Generator("Confidence interval For sample S", 54,
-                                confidenceIntervalFunc, [""])
+                                gen_func, [""])
