@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def dataSummaryFunc(number_values=15, minval=5, maxval=50, format='string'):
+def gen_func(number_values=15, minval=5, maxval=50, format='string'):
     random_list = []
 
     for i in range(number_values):
@@ -23,10 +24,12 @@ def dataSummaryFunc(number_values=15, minval=5, maxval=50, format='string'):
             str(random_list)
         solution = f"The Mean is {mean} , Standard Deviation is {standardDeviation}, Variance is {variance}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return random_list, mean, standardDeviation, variance
 
 
 data_summary = Generator("Mean,Standard Deviation,Variance", 59,
-                         dataSummaryFunc,
+                         gen_func,
                          ["number_values=15", "minval=5", "maxval=50"])
