@@ -1,7 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
+import random
 
 
-def DiceSumProbFunc(maxDice=3, format='string'):
+def gen_func(maxDice=3, format='string'):
     a = random.randint(1, maxDice)
     b = random.randint(a, 6 * a)
 
@@ -24,10 +25,12 @@ def DiceSumProbFunc(maxDice=3, format='string'):
         problem = f"If {a} dice are rolled at the same time, the probability of getting a sum of {b} ="
         solution = f"{count}/{6**a}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, count, 6**a
 
 
 dice_sum_probability = Generator(
     "Probability of a certain sum appearing on faces of dice", 52,
-    DiceSumProbFunc, ["maxDice=3"])
+    gen_func, ["maxDice=3"])
