@@ -1,8 +1,8 @@
-from .__init__ import *
+from ...__init__ import Generator
 import random
 
 
-def meanMedianFunc(maxlen=10, format='string'):
+def gen_func(maxlen=10, format='string'):
     randomlist = random.sample(range(1, 99), maxlen)
     total = 0
     for n in randomlist:
@@ -15,8 +15,10 @@ def meanMedianFunc(maxlen=10, format='string'):
         problem = f"Given the series of numbers {randomlist}. find the arithmatic mean and mdian of the series"
         solution = f"Arithmetic mean of the series is {mean} and Arithmetic median of this series is {median}"
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return randomlist, mean, median
 
 
-mean_median = Generator("Mean and Median", 76, meanMedianFunc, ["maxlen=10"])
+mean_median = Generator("Mean and Median", 76, gen_func, ["maxlen=10"])
