@@ -1,9 +1,9 @@
-from .__init__ import *
-
+from ...__init__ import Generator
+import random
 import math
 
 
-def permutationFunc(maxlength=20, format='string'):
+def gen_func(maxlength=20, format='string'):
     a = random.randint(10, maxlength)
     b = random.randint(0, 9)
     answer = int(math.factorial(a) / (math.factorial(a - b)))
@@ -12,8 +12,10 @@ def permutationFunc(maxlength=20, format='string'):
         problem = f"Number of Permutations from {a} objects picked {b} at a time =  "
         solution = str(answer)
         return problem, solution
+    elif format == 'latex':
+        return "Latex unavailable"
     else:
         return a, b, answer
 
 
-permutation = Generator("Permutations", 42, permutationFunc, ["maxlength=20"])
+permutation = Generator("Permutations", 42, gen_func, ["maxlength=20"])
